#!/bin/sh
#
# (C) COPYRIGHT TIVOLI Systems, Inc. 1994-1998
# Unpublished Work
# All Rights Reserved
# Licensed Material - Property of TIVOLI Systems, Inc.
#
# Carole Corley
#
###########################################################
#
# This script stops the LCF DM engine, dm_ep_engine, on 
# all endpoints that have successfully run dm_ep_engine 
# in the past.  When dm_ep_engine starts up, it registers 
# a boot method which we look for in this script to 
# determine if the engine has been running on a 
# particular endpoint.
#
###########################################################
A=`wls /Regions | cut -f1`
policyregion=`echo $A | cut -f1 -d" "`
echo $A
echo $policyregion

tasklibname=Endpoint_k_1
taskname=dm_ep_kill
taskname_nt=dm_ep_kill_nt
tmrname=`uname -a | cut -f2 -d" "`
currentpath=`pwd`
programpath=$currentpath/dm_ux_kill.sh
programpath_nt=$currentpath/dm_nt_kill.cmd

echo "wcrttlib $tasklibname $policyregion"
wcrttlib $tasklibname $policyregion
echo "wcrttask -t $taskname -l $tasklibname -r user -i default $tmrname $programpath"
wcrttask -t $taskname -l $tasklibname -r user -i default $tmrname $programpath
echo "wcrttask -t $taskname_nt -l $tasklibname -r user -i default $tmrname $programpath_nt"
wcrttask -t $taskname_nt -l $tasklibname -r user -i default $tmrname $programpath_nt

#
# Find all endpoint oids and names.  Create a list of
# OID1 NAME1 OID2 NAME2, etc
#
EP=`wep ls | awk '
BEGIN {VALUE=""}
{
   if ($1 != "G")
   {
      nfn = split($1, fn, "#");
      Oid = fn[1];

      if (VALUE == "") {
        VALUE = Oid " " $2;
      }
      else {
        VALUE = VALUE " " Oid " " $2;
      }
   }  
}
END {print VALUE;}'`

#
# Determine if a boot method has ever been registered 
# on this endpoint.  If so, call wstopeng to stop
# the engine on the endpoint.
#
DoIt="FALSE"
Error="FALSE"
for i in $EP
do
  if [ "$DoIt" = "TRUE" ]; then
     # Display message and endpoint name
     echo "Stopping engine on $i"
     Interp=`wep $i | grep interp | cut -f4 -d" "`
     echo $Interp

     # Set flag to try next endpoint OID
     DoIt="FALSE"

     # stop at least one the engine on the endpoint
     wstopeng -z $i > /dev/null 2>&1 &
     if [ "$Interp" = "os400-v3r7" ]; then
     	echo "skip"
     elif [ "$Interp" = "os400-v3r2" ]; then
     	echo "skip"
     elif [ "$Interp" = "w32-ix86" ]; then
        wruntask -l $tasklibname -t $taskname_nt -h @Endpoint:$i
     else
        wruntask -l $tasklibname -t $taskname -h @Endpoint:$i
     fi
     # Quick sleep to keep from starting too 
     # many processes in the background at once
     sleep 1
  elif [ "$Error" = "FALSE" ]; then
     # Check to see if boot method has been registered for this endpoint
     r=`wep boot_method list Sentry_Boot_1 $i 2>/dev/null`
     r2=`echo $r | cut -f1 -d' '`     
     if [ "$r2" = "Boot" ]; then
        # Set flag to stop engine
        DoIt="TRUE"
     else
        # Set flag to skip the next entry in list (ep_name)
        Error="TRUE"
     fi
  else
     # Clear flag so we'll look at the next entry in the list (OID)
     Error="FALSE"
  fi
done

#
# Cleanup
#

echo "wdeltask $taskname $tasklibname"
wdeltask $taskname $tasklibname
echo "wdeltask $taskname_nt $tasklibname"
wdeltask $taskname_nt $tasklibname
echo "wdel $tasklibname"
wdel @TaskLibrary:$tasklibname

